==> purchaser-invoice-manage-saas-domain-0.0.117-sources.jar: com/xforceplus/purchaserinvoicemanagesaas/metadata/PageMeta.java <==
package com.xforceplus.purchaserinvoicemanagesaas.metadata;

/**
 *
 * @author ultraman
 * @since 2024-05-23
 */

public class PageMeta {
    public interface FunctionConfig {
        static String code() {
            return "functionConfig";
        }
        static String name() {
            return "功能点配置";
        }
    }
    public interface InvoicePush {
        static String code() {
            return "invoicePush";
        }
        static String name() {
            return "发票下发履历";
        }
    }
    public interface InvoiceReceive {
        static String code() {
            return "invoiceReceive";
        }
        static String name() {
            return "发票接收履历";
        }
    }
    public interface InvoiceCheck {
        static String code() {
            return "invoiceCheck";
        }
        static String name() {
            return "发票未勾选";
        }
    }
    public interface InvoiceChecked {
        static String code() {
            return "invoiceChecked";
        }
        static String name() {
            return "发票已勾选";
        }
    }
    public interface CustomsPaymentChecked {
        static String code() {
            return "customsPaymentChecked";
        }
        static String name() {
            return "海关缴款书已勾选";
        }
    }
    public interface Operation {
        static String code() {
            return "operation";
        }
        static String name() {
            return "功能运维";
        }
    }
    public interface RiskInvoiceBatchDetail {
        static String code() {
            return "riskInvoiceBatchDetail";
        }
        static String name() {
            return "风险发票批量处理详情列表";
        }
    }
    public interface InvoiceDetailPool {
        static String code() {
            return "invoiceDetailPool";
        }
        static String name() {
            return "发票明细池";
        }
    }
    public interface InvoiceEntrySubmitTable {
        static String code() {
            return "invoiceEntrySubmitTable";
        }
        static String name() {
            return "发票入账提交信息table";
        }
    }
    public interface InvoiceRecogDelete {
        static String code() {
            return "invoiceRecogDelete";
        }
        static String name() {
            return "发票影像删除记录";
        }
    }
    public interface InvoiceVerifyTask {
        static String code() {
            return "invoiceVerifyTask";
        }
        static String name() {
            return "验真请求记录";
        }
    }
    public interface InvoiceDrawbackChecked {
        static String code() {
            return "invoiceDrawbackChecked";
        }
        static String name() {
            return "发票退税已勾选";
        }
    }
    public interface InvoiceEntry {
        static String code() {
            return "invoiceEntry";
        }
        static String name() {
            return "发票入账";
        }
    }
    public interface InvoiceRisk {
        static String code() {
            return "invoiceRisk";
        }
        static String name() {
            return "风险发票";
        }
    }
    public interface InvoiceDetailPoolV2 {
        static String code() {
            return "invoiceDetailPoolV2";
        }
        static String name() {
            return "发票明细池（冗余字段）";
        }
    }
    public interface WithholdingVoucherCheck {
        static String code() {
            return "withholdingVoucherCheck";
        }
        static String name() {
            return "代扣代缴完税凭证勾选";
        }
    }
    public interface NcpInvoicePendingSummaryTable {
        static String code() {
            return "ncpInvoicePendingSummaryTable";
        }
        static String name() {
            return "待处理农产品发票 提交汇总表格";
        }
    }
    public interface InvoicePoolDeleteFailInfo {
        static String code() {
            return "invoicePoolDeleteFailInfo";
        }
        static String name() {
            return "发票池删除失败信息";
        }
    }
    public interface NcpInvoiceJjkcSummaryTable {
        static String code() {
            return "ncpInvoiceJjkcSummaryTable";
        }
        static String name() {
            return "农产品加计扣除 提交、撤回 汇总表";
        }
    }
    public interface NcpInvoiceJjkc {
        static String code() {
            return "ncpInvoiceJjkc";
        }
        static String name() {
            return "发票加计扣除";
        }
    }
    public interface InvoiceWorkflows {
        static String code() {
            return "invoiceWorkflows";
        }
        static String name() {
            return "发票池业务单详情";
        }
    }
    public interface InvoicePool {
        static String code() {
            return "invoicePool";
        }
        static String name() {
            return "发票池";
        }
    }
    public interface InvoiceOfflineCheck {
        static String code() {
            return "invoiceOfflineCheck";
        }
        static String name() {
            return "发票离线勾选";
        }
    }
    public interface CustomsPaymentDrawbackCheck {
        static String code() {
            return "CustomsPaymentDrawbackCheck";
        }
        static String name() {
            return "海关缴款书退税未勾选";
        }
    }
    public interface TenantFunctionConfig {
        static String code() {
            return "tenantFunctionConfig";
        }
        static String name() {
            return "租户功能配置";
        }
    }
    public interface InvoiceDrawbackCheck {
        static String code() {
            return "invoiceDrawbackCheck";
        }
        static String name() {
            return "发票退税未勾选";
        }
    }
    public interface CustomsPaymentCheck {
        static String code() {
            return "customsPaymentCheck";
        }
        static String name() {
            return "海关缴款书未勾选";
        }
    }
    public interface CustomsPaymentDrawbackChecked {
        static String code() {
            return "CustomsPaymentDrawbackChecked";
        }
        static String name() {
            return "海关缴款书退税已勾选";
        }
    }
    public interface NcpInvoicePending {
        static String code() {
            return "ncpInvoicePending";
        }
        static String name() {
            return "待处理农产品发票";
        }
    }
}

==> purchaser-invoice-manage-saas-domain-0.0.228-sources.jar: com/xforceplus/purchaserinvoicemanagesaas/metadata/PageMeta.java <==
package com.xforceplus.purchaserinvoicemanagesaas.metadata;

/**
 *
 * @author ultraman
 * @since 2024-11-20
 */

public class PageMeta {
    public interface RiskInvoiceBatchDetail {
        static String code() {
            return "riskInvoiceBatchDetail";
        }
        static String name() {
            return "风险发票批量处理详情列表";
        }
    }
    public interface InvoiceOperation {
        static String code() {
            return "invoiceOperation";
        }
        static String name() {
            return "发票池运维页面";
        }
    }
    public interface ManualSearchInvoices {
        static String code() {
            return "manualSearchInvoices";
        }
        static String name() {
            return "申请红字确认单手工找蓝票页面配置";
        }
    }
    public interface BizOrderInvoiceMatch {
        static String code() {
            return "bizOrderInvoiceMatch";
        }
        static String name() {
            return "业务单退货返利发票配单";
        }
    }
    public interface BizOrderInvoiceMatchReadyOnly {
        static String code() {
            return "bizOrderInvoiceMatchReadyOnly";
        }
        static String name() {
            return "业务单退货返利发票配单确认页";
        }
    }
    public interface ChildViewTable {
        static String code() {
            return "childViewTable";
        }
        static String name() {
            return "工作流嵌套表格";
        }
    }
    public interface WithholdingVoucherCheckSummaryTable {
        static String code() {
            return "withholdingVoucherCheckSummaryTable";
        }
        static String name() {
            return "代扣代缴提交汇总表格";
        }
    }
    public interface AbnormalInvoice {
        static String code() {
            return "abnormalInvoice";
        }
        static String name() {
            return "国税异常凭证";
        }
    }
    public interface BusinessConfig {
        static String code() {
            return "businessConfig";
        }
        static String name() {
            return "业务配置页面";
        }
    }
    public interface DeductionCheckTable {
        static String code() {
            return "deductionCheckTable";
        }
        static String name() {
            return "抵扣勾选汇总表格";
        }
    }
    public interface FunctionConfig {
        static String code() {
            return "functionConfig";
        }
        static String name() {
            return "功能点配置";
        }
    }
    public interface InvoicePush {
        static String code() {
            return "invoicePush";
        }
        static String name() {
            return "发票下发履历";
        }
    }
    public interface InvoiceReceive {
        static String code() {
            return "invoiceReceive";
        }
        static String name() {
            return "发票接收履历";
        }
    }
    public interface Operation {
        static String code() {
            return "operation";
        }
        static String name() {
            return "功能运维";
        }
    }
    public interface SmartSearchInvoices {
        static String code() {
            return "smartSearchInvoices";
        }
        static String name() {
            return "申请红字确认单智能推荐蓝票页面配置";
        }
    }
    public interface InvoiceVerifyTask {
        static String code() {
            return "invoiceVerifyTask";
        }
        static String name() {
            return "验真请求记录";
        }
    }
    public interface MatchBatchSend {
        static String code() {
            return "matchBatchSend";
        }
        static String name() {
            return "配单下发页面";
        }
    }
    public interface InvoiceChecked {
        static String code() {
            return "invoiceChecked";
        }
        static String name() {
            return "发票已勾选";
        }
    }
    public interface InvoiceDrawbackChecked {
        static String code() {
            return "invoiceDrawbackChecked";
        }
        static String name() {
            return "发票退税已勾选";
        }
    }
    public interface CustomsPaymentChecked {
        static String code() {
            return "customsPaymentChecked";
        }
        static String name() {
            return "海关缴款书已勾选";
        }
    }
    public interface InvoiceDetailPoolV2 {
        static String code() {
            return "invoiceDetailPoolV2";
        }
        static String name() {
            return "发票明细池（冗余字段）";
        }
    }
    public interface InvoiceDetailPool {
        static String code() {
            return "invoiceDetailPool";
        }
        static String name() {
            return "发票明细池";
        }
    }
    public interface InvoicePoolDeleteFailInfo {
        static String code() {
            return "invoicePoolDeleteFailInfo";
        }
        static String name() {
            return "发票池删除失败信息";
        }
    }
    public interface InvoiceEntrySubmitTable {
        static String code() {
            return "invoiceEntrySubmitTable";
        }
        static String name() {
            return "发票入账提交信息table";
        }
    }
    public interface InvoiceRecogDelete {
        static String code() {
            return "invoiceRecogDelete";
        }
        static String name() {
            return "发票影像删除记录";
        }
    }
    public interface InvoiceEntry {
        static String code() {
            return "invoiceEntry";
        }
        static String name() {
            return "发票入账";
        }
    }
    public interface InvoiceWorkflows {
        static String code() {
            return "invoiceWorkflows";
        }
        static String name() {
            return "发票池业务单详情";
        }
    }
    public interface InvoiceRisk {
        static String code() {
            return "invoiceRisk";
        }
        static String name() {
            return "风险发票";
        }
    }
    public interface NcpInvoiceJjkc {
        static String code() {
            return "ncpInvoiceJjkc";
        }
        static String name() {
            return "发票加计扣除";
        }
    }
    public interface InvoiceCheck {
        static String code() {
            return "invoiceCheck";
        }
        static String name() {
            return "发票未勾选";
        }
    }
    public interface TenantFunctionConfig {
        static String code() {
            return "tenantFunctionConfig";
        }
        static String name() {
            return "租户功能配置";
        }
    }
    public interface NcpInvoicePendingSummaryTable {
        static String code() {
            return "ncpInvoicePendingSummaryTable";
        }
        static String name() {
            return "待处理农产品发票 提交汇总表格";
        }
    }
    public interface NcpInvoiceJjkcSummaryTable {
        static String code() {
            return "ncpInvoiceJjkcSummaryTable";
        }
        static String name() {
            return "农产品加计扣除 提交、撤回 汇总表";
        }
    }
    public interface WithholdingVoucherCheck {
        static String code() {
            return "withholdingVoucherCheck";
        }
        static String name() {
            return "代扣代缴完税凭证勾选";
        }
    }
    public interface InvoiceOfflineCheck {
        static String code() {
            return "invoiceOfflineCheck";
        }
        static String name() {
            return "发票离线勾选";
        }
    }
    public interface InvoicePool {
        static String code() {
            return "invoicePool";
        }
        static String name() {
            return "发票池";
        }
    }
    public interface InvoiceDrawbackCheck {
        static String code() {
            return "invoiceDrawbackCheck";
        }
        static String name() {
            return "发票退税未勾选";
        }
    }
    public interface CustomsPaymentDrawbackCheck {
        static String code() {
            return "CustomsPaymentDrawbackCheck";
        }
        static String name() {
            return "海关缴款书退税未勾选";
        }
    }
    public interface CustomsPaymentCheck {
        static String code() {
            return "customsPaymentCheck";
        }
        static String name() {
            return "海关缴款书未勾选";
        }
    }
    public interface CustomsPaymentDrawbackChecked {
        static String code() {
            return "CustomsPaymentDrawbackChecked";
        }
        static String name() {
            return "海关缴款书退税已勾选";
        }
    }
    public interface NcpInvoicePending {
        static String code() {
            return "ncpInvoicePending";
        }
        static String name() {
            return "待处理农产品发票";
        }
    }
}
